@@ -7,7 +7,11 @@ from .core import (  # noqa: F401
     ParameterRenamer,
     RegexParameterRenamer,
 )
-from .decorators import command as command, group as group  # noqa: F401
+from .decorators import (  # noqa: F401  # noqa: F401
+    command as command,
+    configuration_option as configuration_option,
+    group as group,
+)
 from .types import ClassUnion as ClassUnion, List as List  # noqa: F401  # noqa: F401
 
 del _version  # noqa: F821
